Downloads an online RDS file into a tempfile and reads it. If the download fails, a message is emitted and the vignette exits.
Downloads an online RDS file into a tempfile and reads it. If the download fails, a message is emitted and the vignette exits.